@@ -1,15 +1,13 @@
 # -*- coding: UTF-8 -*-
-from datetime import datetime
-import json, os, inspect
+import json, os
 from pymongo import MongoClient
 from lisa.server.service import configuration
 from wit import Wit
 from lisa.server.web.manageplugins.models import Intent as oIntents
-
 import gettext
+import lisa.server
 
-path = os.path.realpath(os.path.abspath(os.path.join(os.path.split(
-    inspect.getfile(inspect.currentframe()))[0],os.path.normpath("lang"))))
+path = os.path.normpath(str(lisa.server.__path__[0]) + "/lang/")
 _ = translation = gettext.translation(domain='intents', localedir=path, fallback=True,
                                       languages=[configuration['lang']]).ugettext
 
@@ -22,7 +20,6 @@ class Intents:
         self.database = mongo.lisa
         self.wit = Wit(self.configuration['wit_token'])
 
-
     def list(self, jsonInput):
         intentstr = []
         listintents = self.wit.get_intents()
@@ -31,7 +28,6 @@ class Intents:
                 print witintent
                 if witintent["name"] == oIntent.name and 'metadata' in witintent:
                     if witintent['metadata']:
-                        metadata = {}
                         metadata = json.loads(witintent['metadata'])
                         intentstr.append(metadata['tts'])
 
